@@ -26,7 +26,7 @@ from giza.config.base import ConfigurationBase
 
 class RuntimeStateConfig(ConfigurationBase):
     _option_registry = [ 'length', 'days_to_save', 'builder_to_delete',
-                         'git_branch', 'git_sign_patch',
+                         'git_branch', 'git_sign_patch', 'serial_sphinx',
                          'clean_generated', 'include_mask', 'push_targets', 'dry_run' ]
 
     def __init__(self, obj=None):
@@ -226,7 +226,7 @@ class RuntimeStateConfig(ConfigurationBase):
                 value[idx] = builder
 
             if builder not in sphinx.builders.BUILTIN_BUILDERS:
-                raise TypeError
+                raise TypeError("{0} is not a valid builder".format(builder))
 
         self.state['builder'] = value
 
@@ -262,3 +262,17 @@ class RuntimeStateConfig(ConfigurationBase):
             self.state['languages_to_build'] = value
         else:
             self.state['languages_to_build'] = [value]
+
+    @property
+    def dry_run(self):
+        if 'dry_run' not in self.state:
+            return False
+        else:
+            return self.state['dry_run']
+
+    @dry_run.setter
+    def dry_run(self, value):
+        if value in (True, False):
+            self.state['dry_run'] = value
+        else:
+            raise TypeError
