@@ -54,7 +54,6 @@ class SphinxConfig(RecursiveConfigurationBase):
         # register the global config, but use our ingestion
         # super(SphinxConfig, self).__init__(None, conf)
 
-        self._conf = None
         self._state = {}
         self._raw = {}
         self.conf = conf
@@ -81,23 +80,37 @@ class SphinxConfig(RecursiveConfigurationBase):
 
         base = self._raw[lookup]
 
-        for i in ['excluded_files', 'tags', 'languages']:
+        for i in ['excluded', 'tags', 'languages']:
             if i in base:
                 setattr(self, i, base[i])
 
         m = 'registered language, builder, and edition options: ({0}, {1}, {2})'
         logger.debug(m.format(language, builder, edition))
 
+    @property
+    def build_output(self):
+        if 'edition' in self.conf.project and self.conf.project.edition != self.conf.project.name:
+            dirname = hyph_concat(self.builder, self.edition)
+        else:
+            dirname = self.builder
+
+        path = os.path.join(self.conf.paths.projectroot, self.conf.paths.branch_output, dirname)
+
+        if 'build_output' not in self.state:
+            self.state['build_output'] = path
+
+        return path
+
     @property
     def builder(self):
         return self.state['builder']
 
     @property
-    def excluded_files(self):
-        if 'excluded_files' not in self.state:
+    def excluded(self):
+        if 'excluded' not in self.state:
             return []
         else:
-            return self.state['excluded_files']
+            return self.state['excluded']
 
     @property
     def tags(self):
@@ -114,13 +127,13 @@ class SphinxConfig(RecursiveConfigurationBase):
         else:
             raise Exception('{0} is not a valid sphinx builder'.format(value))
 
-    @excluded_files.setter
-    def excluded_files(self, value):
+    @excluded.setter
+    def excluded(self, value):
         if not isinstance(value, list):
-            logger.error('excluded_files must be a list.')
+            logger.error('excluded files must be a list.')
             raise TypeError
         else:
-            self.state['excluded_files'] = value
+            self.state['excluded'] = value
 
     @tags.setter
     def tags(self, value):
