@@ -66,13 +66,15 @@ def get_sphinx_args(sconf, conf):
 
     o.append('-b {0}'.format(sconf.builder))
 
-    if (is_parallel_sphinx(pkg_resources.get_distribution("sphinx").version) and
-        'editions' not in sconf):
-        o.append(' '.join( [ '-j', str(cpu_count() + 1) ]))
+    if is_parallel_sphinx(pkg_resources.get_distribution("sphinx").version):
+        if 'serial_sphinx' in conf.runstate and conf.runstate.serial_sphinx is True:
+            pass
+        else:
+            o.append(' '.join( [ '-j', str(cpu_count()) ]))
 
     o.append(' '.join( [ '-c', conf.paths.projectroot ] ))
 
-    if 'language' in sconf:
+    if 'language' in sconf and sconf.language is not None:
         o.append("-D language='{0}'".format(sconf.language))
 
     return ' '.join(o)
@@ -106,9 +108,13 @@ def output_sphinx_stream(out, conf):
         l = path_normalization(l, full_path, conf)
 
         if l.startswith('InputError: [Errno 2] No such file or directory'):
-            l = path_normalization(l.split(' ')[-1].strip()[1:-2], full_path, conf)
-            printable[idx-1] += ' ' + l
-            l = None
+            try:
+                l = path_normalization(l.split(' ')[-1].strip()[1:-2], full_path, conf)
+                printable[idx-1] += ' ' + l
+                l = None
+            except IndexError:
+                logger.error("error processing log: {0}".format(l))
+                continue
         elif l.startswith('source/includes/generated/overview.rst'):
             continue
         elif l.startswith('source/meta/includes.txt'):
@@ -172,9 +178,9 @@ def run_sphinx(builder, sconf, conf):
 
     sphinx_cmd = cmd.format(get_sphinx_args(sconf, conf),
                             os.path.join(conf.paths.projectroot, conf.paths.branch_output),
-                            builder,
+                            os.path.basename(sconf.build_output),
                             os.path.join(conf.paths.projectroot, conf.paths.branch_source),
-                            os.path.join(conf.paths.projectroot, conf.paths.branch_output, builder))
+                            sconf.build_output)
 
     out = command(sphinx_cmd, capture=True, ignore=True)
     # out = sphinx_native_worker(sphinx_cmd)
@@ -239,6 +245,6 @@ def finalize_sphinx_build(sconf, conf, app):
     elif target == 'singlehtml':
         finalize_single_html_tasks(target, conf, app)
     elif target == 'latex':
-        pdf_tasks(target, conf, app)
+        pdf_tasks(sconf, conf, app)
     elif target == 'gettext':
         gettext_tasks(conf, app)
